JoinTable

Struct JoinTable 

pub struct JoinTable<'txn> { /* private fields */ }
A table that maps IDs of elements to IDs of other elements to which they are related. For example, mapping Nodes to the Ways that they are part of, or mapping any elements (Nodes, Ways, Relations) to the Relations that the elements are members of.

Implementations

Source

impl<'txn> JoinTable<'txn>

pub fn get(&self, id: u64) -> impl Iterator<Item = u64> + 'txn

Given an element ID, returns the IDs of elements it is related to in this table. Returns an iterator since there may be multiple values for a given key.