pub struct JoinTable<'txn> { /* private fields */ }Expand description
A table that maps IDs of elements to IDs of other elements to which they are related. For example, mapping Nodes to the Ways that they are part of, or mapping any elements (Nodes, Ways, Relations) to the Relations that the elements are members of.
Implementations